/*
 * Copyright 2005, 2006 University of Leiden.
 *
 * This file is part of MIA+EWS.
 *
 * MIA+EWS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MIA+EWS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MIA; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/*******************************************************************************
* E.S.O. - VLT project
*
* "@(#) $Id: optical_train.h,v 1.4 2002/05/08 21:24:48 jdejong Exp $"
*
* who       when      what
* --------  --------  ----------------------------------------------
* jdejong 2002-05-08  imported
*/

/************************************************************************
 *
 *----------------------------------------------------------------------
 */

/* $Id: optical_train.h,v 1.4 2002/05/08 21:24:48 jdejong Exp $ */

#ifndef _OPTICAL_TRAIN_TABLE_H
#define _OPTICAL_TRAIN_TABLE_H
/*----------------------------------------------------------------------- */
/* Optical Train table FITS binary tables routines                       */
/*----------------------------------------------------------------------- */
#include "VLTItable.h"

typedef struct      /* table definition for optical_train table */
{
  table_def *def;       /* basic table information */
  long   row;           /* last row (0-rel) read or written, -1=> none. */
  int    index_col;     /* Index column number (0-rel) */
  int    telescope_col; /* Telescope number column number */
  int    dly_line_col;  /* Delay line designator column number */
  int    lab_beam_col;  /* M16 input channel */
  int    switchyard_col;/* Switchyard option column number */
  /* keyword data */
  char*  arrnam;        /* Name of the array */
  char   *date_obs;     /* observing date */
} optical_train_table_def;

typedef struct      /* structure used for optical_train_table row */
{
  int    index;      /* Index number number */
  int    telescope;  /* Telescope index number */
  int    dly_line;   /* Delay line  used identifier */
  int    lab_beam;   /* M16 input channel  */
  int    switchyard; /* Switchyard option */
  table_row *raw;    /* generic table row */
} optical_train_table_row;

/* public functions */

/* optical_train_table_row functions */
optical_train_table_row* make_optical_train_table_row(optical_train_table_def* table);
/*----------------------------------------------------------------------- */
/*   Make an optical_train_table_row structure                            */
/*   Inputs:                                                              */
/*      table     pointer to optical_train_table table structure          */
/*   Returns:                                                             */
/*      An optical_train_table_row structure pointer ; NULL => failure    */
/*      Data pointers set to generic structure values                     */
/*----------------------------------------------------------------------- */

/* delete an optical_train_table_row structure */
void kill_optical_train_table_row (optical_train_table_row *row);
/*----------------------------------------------------------------------- */
/*   Delete an optical_train_table_row structure                          */
/*   Inputs:                                                              */
/*      row    pointer to the optical_train_table_row structure.          */
/*----------------------------------------------------------------------- */

/* optical_train_table functions */
optical_train_table_def* 
make_optical_train_table_def(fitsfile *fptr, char *arrnam, char *date_obs,
			      int *ierr);
/*----------------------------------------------------------------------- */
/*   Make a new optical_train_table in an open FITS file                  */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*      arrnam    Array name                                              */
/*      date_obs  Observing date                                          */
/*   Output:                                                              */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      A optical_train_table_def pointer; NULL indicates failure         */
/*----------------------------------------------------------------------- */

optical_train_table_def* 
open_optical_train_table(fitsfile *fptr, int *ierr);
/*----------------------------------------------------------------------- */
/*   Open an existing optical_train_table in the active FITS file         */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*   Output:                                                              */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      An optical_train_table_def pointer; NULL indicates failure        */
/*----------------------------------------------------------------------- */

int read_optical_train_table(fitsfile *fptr,  optical_train_table_def* table, 
			    optical_train_table_row *row, long row_number,
			    int *ierr);
/*----------------------------------------------------------------------- */
/*   Read the next row from an optical_train_table                        */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*      table     table definitions structure from open or create         */
/*      row_number which row (1-rel) in the table                         */   
/*                 -1 => next row                                         */  
/*   Input/output:                                                        */
/*      row       pointer to an extant row structure                      */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      0 if successful, else failed                                      */
/*----------------------------------------------------------------------- */

int write_optical_train_table(fitsfile *fptr, optical_train_table_def *table, 
			     optical_train_table_row *row,  long row_number,
			     int *ierr);
/*----------------------------------------------------------------------- */
/*   Write  the next row to an optical_train_table                               */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*      table     table definitions structure from open or create         */
/*      row       pointer to an extant row structure                      */
/*      row_number which row (1-rel) in the table                         */
/*                 -1 => next row                                         */  
/*   Input/output:                                                        */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      0 if successful, else failed                                      */
/*----------------------------------------------------------------------- */

int close_optical_train_table(fitsfile *fptr, optical_train_table_def* table, 
			     int *ierr);
/*----------------------------------------------------------------------- */
/*   Close an open optical_train_table, associated structures are        */
/*   destroyed                                                            */
/*   Note: this closes the full FITS file                                 */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*   Returns:                                                             */
/*      0 if successful, else failed                                      */
/*----------------------------------------------------------------------- */

void kill_optical_train_table_def (optical_train_table_def* table);
/*----------------------------------------------------------------------- */
/*   Delete an optical_train_table structure                             */
/*   Inputs:                                                              */
/*      table     table definitions structure from open or create         */
/*----------------------------------------------------------------------- */

#endif /* end OPTICAL_TRAIN_TABLE_H */
/* */
